@@ -230,9 +230,11 @@ class Exper(object):
     self.update_nbytes()
 
 
-  def write(self, path = None, name = None , history = 'Created from Spacegrids ' , insert_dual = True ):
+  def write(self, path = None, name = None , history = 'Created from Spacegrids ' , insert_dual = True , *args, **kwargs):
     """Write Exper to Netcdf file.
 
+    *args, **kwargs are passed on to netcdf io function (Dataset() ).
+
     Args:
       path: (str) path to the directory where the file will go (e.g. 'data/' or '/home/me/', default pwd).
       name: (str) file name (e.g. "foo.nc")
@@ -267,7 +269,7 @@ class Exper(object):
 
       try:
         # using io_sg version of netcdf_file. May use ScientificIO or Scipy
-        file_handle = netcdf_file(name , 'w')
+        file_handle = netcdf_file(name , 'w', *args, **kwargs)
 
       except (IOError, RuntimeError):
         print '... FAIL'
@@ -291,7 +293,7 @@ class Exper(object):
 
 
       
-  def load(self,varnames, squeeze_field = True, ax=None, name_suffix='_cat', new_coord_name = 'gamma', new_coord= None ):
+  def load(self,varnames, squeeze_field = True, ax=None, name_suffix='_cat', new_coord_name = 'gamma', new_coord= None,slices = None, slice_suffix = '_sliced' , *args, **kwargs):
     """
     Load a variable or list of variables contained in varnames into Exper. 
 
@@ -300,6 +302,8 @@ class Exper(object):
     if self.path is to a file (an Experiment file), the variable will be loaded from that file.
     if self.path is to a directory (an experiment dir), the variable will be loaded from Netcdf files inside that directory.
 
+    *args, **kwargs are passed on to the 'netcdf_file' function that handles opening of the file. 
+
     Args:
       varnames: (str or list) var name or list of the var names to load
       squeeze_field (boolean):	Flag to squeeze Field on loading (default True)	
@@ -307,12 +311,26 @@ class Exper(object):
       name_suffix (str): passed on to the concatenate function
       new_coord_name (str): passed on to the concatenate function
       new_coord (Coord): passed on to the concatenate function
+      slices: (tuple of slice, Coord and Ax objects) slices to take. No slicing if None.     
+      slice_suffix: (str) suffix to add to variable name in case of slicing
+
 
     Returns:
       None
 
     Raises:
-      IOError: if path to Netcdf file not valid (very rare under automatic sg usage).
+      IOError: if path to Netcdf file not valid (rare under automatic sg usage).
+
+    Examples:
+
+    >>> P.load('O_temp',slices=(Z,0,X,50))
+    >>> E.show()
+    DPO
+    ----------
+    O_temp_sliced 
+    >>> TEMP = E['O_temp_sliced']
+    >>> TEMP.grid
+    (latitude)
     """  
 
 # --> this load is a method of Exper
@@ -348,7 +366,9 @@ class Exper(object):
       for filepath in paths:
 
         try:       
-          file = netcdf_file(filepath,'r')
+          file = netcdf_file(filepath,'r', *args, **kwargs)
+
+          # extract the filename fnm from the path:
           fnm = os.path.split(filepath)[1]
         except IOError:
           raise IOError('Cannot open %s'%filepath)
@@ -356,7 +376,7 @@ class Exper(object):
 
           if varname in file.variables:
            
-            F.append(cdfread(filepath,varname,self.cstack,self.axes))
+            F.append(cdfread(filepath,varname,self.cstack,self.axes,slices =slices, slice_suffix = slice_suffix))
             fnames.append(fnm)
 
           file.close()
@@ -372,11 +392,12 @@ class Exper(object):
 
         new_field = concatenate(F,ax=ax, name_suffix=name_suffix, new_coord_name = new_coord_name, strings = fnames, new_coord= new_coord   )
 
+   
         # insert Field into experiment
         if squeeze_field:
-          self.insert(what = (varname, squeeze( new_field ) ) ) 
+          self.insert(what = (new_field.name, squeeze( new_field ) ) ) 
         else:
-          self.insert(what = (varname, new_field ) ) 
+          self.insert(what = (new_field.name, new_field ) ) 
 
     self.update_nbytes() 
 
@@ -389,6 +410,8 @@ class Exper(object):
 
     Argument what can also be a list of (name,value) pairs, in which case the entire collection of pairs will be inserted.   
 
+    At the moment, 'insert' forces key van object name to be consistent. Might change in future. Also copies field object to do this.
+
     Args:
       what: (length 2 tuple or list thereof) name and value: (name, value).
 
@@ -405,6 +428,7 @@ class Exper(object):
 
     else:
 
+      # value here refers to the name, value pairs, not Field value
       name = what[0]
       value = what[1]
 
